@@ -1,11 +1,11 @@
-gwr.robust<-function(formula, data, regression.points, bw,filtered=FALSE, kernel = "bisquare", adaptive = FALSE, p = 2, theta = 0, longlat = F, dMat, F123.test = F,maxiter=20,cut.filter= 3,cut1=2,cut2=3,delta=1.0e-5) 
+gwr.robust<-function(formula, data, bw,filtered=FALSE, kernel = "bisquare", adaptive = FALSE, p = 2, theta = 0, longlat = F, dMat, F123.test = F,maxiter=20,cut.filter= 3,cut1=2,cut2=3,delta=1.0e-5) 
     {    	   
     	W.vect<-NULL 	
-    	res1<- gwr.basic(formula, data, regression.points, bw, kernel, adaptive, p, theta, longlat, dMat, F123.test, T,W.vect)
+    	res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
     	if(filtered==TRUE){
     		W.vect<-as.numeric(abs(res1$SDF$Stud_residual)<cut.filter)
     		
-    	  	res1<-gwr.basic(formula, data, regression.points, bw, kernel, adaptive, p, theta, longlat, dMat, F123.test, T,W.vect)
+    	  	res1<-gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
     	}
     	
     	else{ # Automatic approach
@@ -30,7 +30,7 @@ gwr.robust<-function(formula, data, regression.points, bw,filtered=FALSE, kernel
     
     		while(diffmse>delta & iter<maxiter) {
    		 	old.mse<-mse
-			res1<- gwr.basic(formula, data, regression.points, bw, kernel, adaptive, p, theta, longlat, dMat, F123.test, T,W.vect)
+			res1<- gwr.basic(formula=formula, data=data, bw=bw, kernel=kernel, adaptive=adaptive, p=p, theta=theta, longlat=longlat, dMat=dMat, F123.test=F123.test, cv=T,W.vect=W.vect)
     	
     			err<-res1$SDF$residual 
     			mse<- sum(err*err)/length(err)
