@@ -1,4 +1,4 @@
-﻿#include <R.h>
+#include <R.h>
 #include <Rinternals.h>
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
@@ -32,6 +32,11 @@ extern SEXP GWmodel_mk_dist_vec(SEXP, SEXP, SEXP);
 extern SEXP GWmodel_rss(SEXP, SEXP, SEXP);
 extern SEXP GWmodel_tri_wt_mat(SEXP, SEXP);
 extern SEXP GWmodel_tri_wt_vec(SEXP, SEXP);
+extern SEXP GWmodel_scgwr_pre(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP GWmodel_scgwr_loocv(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP GWmodel_scgwr_reg(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP GWmodel_AICc1(SEXP, SEXP, SEXP, SEXP);
+extern SEXP GWmodel_gwr_diag1(SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"GWmodel_AICc",              (DL_FUNC) &GWmodel_AICc,              4},
@@ -63,6 +68,11 @@ static const R_CallMethodDef CallEntries[] = {
     {"GWmodel_rss",               (DL_FUNC) &GWmodel_rss,               3},
     {"GWmodel_tri_wt_mat",        (DL_FUNC) &GWmodel_tri_wt_mat,        2},
     {"GWmodel_tri_wt_vec",        (DL_FUNC) &GWmodel_tri_wt_vec,        2},
+    {"GWmodel_scgwr_pre",         (DL_FUNC) &GWmodel_scgwr_pre,         7},
+    {"GWmodel_scgwr_loocv",       (DL_FUNC) &GWmodel_scgwr_loocv,       9},
+    {"GWmodel_scgwr_reg",         (DL_FUNC) &GWmodel_scgwr_reg,         11},
+	{"GWmodel_AICc1",              (DL_FUNC) &GWmodel_AICc1,             4},
+	{"GWmodel_gwr_diag1",          (DL_FUNC) &GWmodel_gwr_diag1,        4},
     {NULL, NULL, 0}
 };
 
